@@ -229,7 +229,16 @@ class Deezer:
             if track["VERSION"] != "":
                 title += " " + track["VERSION"]
 
-        if "featuring" in track["SNG_CONTRIBUTORS"]:
+        def should_include_featuring():
+            # Checks if the track title already have the featuring artists in its title
+            feat_keywords = ["feat.", "featuring", "ft."]
+
+            for keyword in feat_keywords:
+                if keyword in title.lower():
+                    return False
+            return True
+
+        if should_include_featuring() and "featuring" in track["SNG_CONTRIBUTORS"]:
             featuring_artists_data = track["SNG_CONTRIBUTORS"]["featuring"]
             featuring_artists = featuring_artists_data[0]
             for i in range(1, len(featuring_artists_data)):
@@ -644,7 +653,7 @@ class Deezer:
             bytes -- Binary data of the image
         """
 
-        if "DATA" in artist:
+        if not "ART_PICTURE" in artist and "DATA" in artist:
             artist = artist["DATA"]
 
         return self._get_poster(artist["ART_PICTURE"], size=size, ext=ext)
@@ -849,16 +858,18 @@ class Deezer:
         del tags["_albumart"]
 
         for key, val in tags.items():
-            audio[key] = str(val)
+            if val:
+                audio[key] = str(val)
         audio.save()
 
-        cover_handle = ID3(path)
-        cover_handle["APIC"] = APIC(
-            type=3,
-            mime=cover["mime_type"],
-            data=cover["image"]
-        )
-        cover_handle.save(path)
+        if cover:
+            cover_handle = ID3(path)
+            cover_handle["APIC"] = APIC(
+                type=3,
+                mime=cover["mime_type"],
+                data=cover["image"]
+            )
+            cover_handle.save(path)
 
         return True
 
@@ -872,16 +883,19 @@ class Deezer:
         audio = File(path)
         audio.delete()
 
-        pic = mutagen.flac.Picture()
-        pic.data = tags["_albumart"]["image"]
-
-        audio.clear_pictures()
-        audio.add_picture(pic)
-
+        cover = tags["_albumart"]
         del tags["_albumart"]
 
+        if cover:
+            pic = mutagen.flac.Picture()
+            pic.data = cover["image"]
+
+            audio.clear_pictures()
+            audio.add_picture(pic)
+
         for key, val in tags.items():
-            audio[key] = str(val)
+            if val:
+                audio[key] = str(val)
         audio.save()
 
         return True
